==> Blind-src-V2.43.zip: Blind-2.43/cmds/s.c <==
static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.43/cmds/RCS/s.c,v 2.43 1995/03/20 01:43:09 zeus Exp zeus $";

/*
 *
 * $Log: s.c,v $
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * *** empty log message ***
 *
 *
 */

#define NOTIMEB
 
#include "../protos/common.h"
#include "../protos/prototypes.h"
#include "../protos/enterturn-g.h"
#include "../protos/cmds.h"
#include "../protos/cmds-g.h"
/*#include "../protos/misc-g.h"*/

extern char tbuf[];
extern int pos;
extern int comment;
extern char err_tmp[];
extern int groupno;

void
s_cmd (char *buf, player * P)
{
  group *g;
  int i;

#ifdef UPGRADE
  fleetname *fl;
  char v[80];

#endif

  planet *p;

  hstrcpy (tbuf, buf);
  pos = 0;
  (void) next_token ();

#ifdef UPGRADE
  hstrcpy (v, next_token ());
  fl = matchfleet (P, v);
  if (!fl)
    g = matchgroup (P, v);
  else
    g = NULL;
  if (!g && !fl)
#else
  g = ninputgroup (P);
  if (!g)
#endif

  {
    error (err_tmp);
    return;
  }

#ifdef UPGRADE
  if (fl)
  {
    for (g = P->groups; g; g = g->next)
    {
      if ((g->fleet == fl) && (g->dist))
      {
	error ("Fleet is in hyperspace\n");
	return;
      }
      if ((g->fleet == fl) && (!g->type->drive))
      {
	error ("Fleet cannot move");
	return;
      }
    }
  }
  else
#endif

  {
    if (group_check (P, g, NULL, groupno, G_DIST | G_DRIVES))
    {
      error (err_tmp);
      return;
    }
  }
  p = ninputplanet ();
  if (!p)
  {
    error (err_tmp);
    return;
  }

#ifdef UPGRADE
  if (fl)
  {
    for (g = P->groups; g; g = g->next)
    {
      if (g->fleet == fl)
      {
	send (g, p);
      }
    }
    extra_token ();
    return;
  }
#endif

  i = ngeti ();
  if (i == -3)
    comment = 1;
  if (i == BADI)
  {
    error (err_tmp);
    return;
  }
  if (i == MISSINGI)
    i = 0;			/* Too few tokens */
  if (i > g->ships)
  {
    i = g->ships;
    sprintf (err_tmp, "Only %d ships can be sent.\n", i);
    error (err_tmp);
  }
  if (i <= 0)
    i = g->ships;
  if (i != g->ships)
    g = new_group (P, g, i);

#ifdef UPGRADE
  g->fleet = NULL;
#endif

  send (g, p);
  extra_token ();
}

==> Blind-src-V2.45.0.2.zip: Blind-2.45/cmds/s.c <==
static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/cmds/RCS/s.c,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $";

/*
 *
 * $Log: s.c,v $
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * *** empty log message ***
 *
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * *** empty log message ***
 *
 *
 */

#define NOTIMEB
 
#include "../protos/common.h"
#include "../protos/prototypes.h"
#include "../protos/enterturn-g.h"
#include "../protos/cmds.h"
#include "../protos/cmds-g.h"

extern char tbuf[];
extern int pos;
extern int comment;
extern char err_tmp[];
extern int groupno;

void s_cmd_rcsid (void);
void
s_cmd_rcsid (void)
{
  printf ("%s\n",rcsid);
}

void
s_cmd (char *buf, player * P)
{
  group *g;
  int i;

#ifdef UPGRADE
  fleetname *fl;
  char v[MAXTEXT];

#endif

  planet *p;

  hcstrcpy (tbuf, buf);
  pos = 0;
  (void) next_token ();

#ifdef UPGRADE
  hstrncpy (v, next_token (),MAXTEXT);
  fl = matchfleet (P, v);
  if (!fl)
    g = matchgroup (P, v);
  else
    g = NULL;
  if (!g && !fl)
#else
  g = ninputgroup (P);
  if (!g)
#endif

  {
    error (err_tmp);
    return;
  }

#ifdef UPGRADE
  if (fl)
  {
    for (g = P->groups; g; g = g->next)
    {
      if ((g->fleet == fl) && (g->dist))
      {
        if (g->dist == UPG)
        {
          sprintf (err_tmp,"Group %d has been upgraded - fleet can not move\n",
            ptonum (P->groups, g));
          error (err_tmp);
        }
        else
	  error ("Fleet is in hyperspace\n");
	return;
      }
      if ((g->fleet == fl) && (!g->type->drive))
      {
	error ("Fleet cannot move");
	return;
      }
    }
  }
  else
#endif

  {
    if (group_check (P, g, NULL, groupno, G_DIST | G_DRIVES | G_NOUPG))
    {
      error (err_tmp);
      return;
    }
  }
  p = ninputplanet ();
  if (!p)
  {
    error (err_tmp);
    return;
  }

#ifdef UPGRADE
  if (fl)
  {
    for (g = P->groups; g; g = g->next)
    {
      if (g->fleet == fl)
      {
	send (g, p);
      }
    }
    extra_token ();
    return;
  }
#endif

  i = ngeti ();
  if (i == NAI)
    comment = 1;
  if (i == BADI)
  {
    error (err_tmp);
    return;
  }
  if (i == MISSINGI)
    i = 0;			/* Too few tokens */
  if (i > g->ships)
  {
    i = g->ships;
    sprintf (err_tmp, "Warning! Only %d ships can be sent.\n", i);
    error (err_tmp);
  }
  if (i <= 0)
    i = g->ships;
  if (i != g->ships)
    g = new_group (P, g, i);

#ifdef UPGRADE
  g->fleet = NULL;
#endif

  send (g, p);
  extra_token ();
}
